*--------------------------------------------------------------------------*;
%let ProgramName = control ;
%let Extension   = sas ;
%let Version     = 3.5 ;
%let Root        = /data/cahpsmmc/analysis_program/version 3.5 ;
%let ProgramPath = /programs/ ;
%let Created     = 24 Aug 2005 ;
%let Author      = Matthew J. Cioffi ;
%let Type        = Program ;

*--------------------------------------------------------------------------*
| What are the required input data sets and macros needed by the program.  |
      MACROS: cahps35.sas
      DATA  : plandtal.dat
              test.sas7bdat
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| What are the permanent output datasets created by the program or where   |
| are all the datasets stored if there are many.                           |
      The data sets created by the CAHPS macro.
*--------------------------------------------------------------------------*;
 
***********
* Purpose *
     Program that invokes the CAHPS macro to perform basic analysis for 
     the CAHPS Adult Core Survey.  This program should be modified
     to meet the needs of the user. It prepares the data set by cleaning, 
     reverse coding and adding variables that are needed by the CAHPS macro.

*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| Macro Variables                                                          |
*--------------------------------------------------------------------------*;
%let Filename    = &ProgramName..&Extension  ; 

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
|     in       -  SAS data set to be used as input.                        |
|     out      -  Permanent SAS data sets created by Macro stored here.    |
|                   ** OUT is required by the CAHPS macro **               |
|     library  -  Location of the library for using permanent formats.     |
|                                                                          |
|     logfile  -  Path and filename for the SAS log file.                  |
|     outfile  -  Path and filename for storing SAS procedure output.      |
|     cahps    -  Path and filename for the CAHPS macro.                   |
|     plan_dat -  Path and filename for the plan detail information.       |
*--------------------------------------------------------------------------*;

libname in        "&root./sasdata/" ;
libname out       "&root./sasdata/control/" ;
libname library   "&root./sascatalog/" ;

filename _all_ clear ;
filename logfile  "&root./output/logs/&ProgramName..log" ;
filename outfile  "&root./output/&ProgramName..txt" ;
filename cahps    "&root./programs/cahps35.sas" ;
filename plan_dat "&root./data_other/plandtal.dat" ;


*--------------------------------------------------------------------------*
| Redirect output and logs to the file referenced by outfile and logfile.  |
*--------------------------------------------------------------------------*;

proc printto print = outfile new
             log   = logfile new
             ;
run;


*--------------------------------------------------------------------------*
|   Clear all titles and footnotes                                         |
*--------------------------------------------------------------------------*;

title ;
footnote ;

run ;


*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox (logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
        ;
run ;



*--------------------------------------------------------------------------*
| Begin Preparation of data set for CAHPS macro                            |
*--------------------------------------------------------------------------*;

data adult ( drop = i ) ;
   set in.test ;

*--------------------------------------------------------------------------*
| Recodes numeric plan variables to character to simplify interpretation   |
| of the resultant data sets and reports.                                  |
*--------------------------------------------------------------------------*;

   length plan $ 16 ;

   if      planid = 1 then plan = 'HMO_A_URBAN' ;
   else if planid = 2 then plan = 'HMO_B_URBAN' ;
   else if planid = 7 then plan = 'HMO_C_URBAN' ;
   else if planid = 4 then plan = 'HMO_B_RURAL' ;
   else if planid = 5 then plan = 'HMO_C_RURAL' ;
   else if planid = 6 then plan = 'HMO_BE_1' ;

*--------------------------------------------------------------------------*
| Create a variable named VISITS which is required by the CAHPS macro.     |
| If no variable exisits for the number of visits, VISITS = 0 by default.  |
*--------------------------------------------------------------------------*;

   visits = q21 ;

*--------------------------------------------------------------------------*
| If there are children records in the data set and the user wants the     |
| the macro to process them as children records, then a CHILD variable     |
| needs to be created.  For each record that is a child the value should   |
| be set to 1, otherwise it can be set to any other number.  If the user   |
| does not supply the CHILD variable, the macro creates one and sets it to |
| zero.                                                                    |
*--------------------------------------------------------------------------*;

*  child = 1 ;

*--------------------------------------------------------------------------*
| Recodes dichotomous, yes/no, variables from 1/2 to 1/0.                  |
*--------------------------------------------------------------------------*;

   array yn q05 q13 ;
   do i = 1 to dim ( yn ) ;
           if yn [i] = 0 then yn [i] = . ;
      else if yn [i] = 2 then yn [i] = 0 ;
   end ;

*--------------------------------------------------------------------------*
| REVERSE code items for which never = positive and always = negative.     |
*--------------------------------------------------------------------------*;

   array rev q24 ;
   do i = 1 to dim ( rev ) ;
      if rev [i] in (1, 2, 3, 4) then rev [i] = 5 - rev [i] ;
      else                            rev [i] = . ;
   end ;

*--------------------------------------------------------------------------*
| Cleans variables general health rating (q39) and age (q40).              |
*--------------------------------------------------------------------------*;

   age = q40 ;
   ghr = q39 ;

   label
      age = "Age of Adult" 
      ghr = "General Health Rating"
   ;

   if ghr not in (1, 2, 3, 4, 5)       then ghr = . ;
   if age not in (1, 2, 3, 4, 5, 6, 7) then age = . ;
run ;

*--------------------------------------------------------------------------*
| ** End Peparation of data set for CAHPS macro **                         |
*--------------------------------------------------------------------------*;



*--------------------------------------------------------------------------*
| Include and compile needed macros.                                       |
*--------------------------------------------------------------------------*;

%include cahps ;


%let _al = ghr age ;

*--------------------------------------------------------------------------*
| Overall Rating Scales - Adults                                           |
*--------------------------------------------------------------------------*;

%cahps(var      = q38,
       vartype  = 2,
       name     = Rating Health Plan,
       adjuster = &_al,
       adj_bars = 1,
       impute   = 1,
       adultkid = 3,
       dataset  = adult,
       outname  = q38 ) ;

%cahps(var      = q31,
       vartype  = 2,
       name     = Rating Quality of Care,
       adjuster = &_al,
       impute   = 1,
       adultkid = 3,
       dataset  = adult,
       outname  = q31 ) ;




*--------------------------------------------------------------------------*
| Composites (How Often Scale) - Adults                                    |
*--------------------------------------------------------------------------*;

%cahps(var      = q15 q17 q19 q24,
       vartype  = 3,
       name     = Getting Care Quickly,
       adjuster = &_al,
       impute   = 1,
       adultkid = 3,
       dataset  = adult,
       outname  = quick );


*--------------------------------------------------------------------------*
| Composites (Problem Scale) - Adults                                      |
*--------------------------------------------------------------------------*;

%cahps(var      = q06 q10 q22 q23,
       vartype  = 4,
       name     = Getting Care Needed, 
       adjuster = &_al,
       impute   = 1,
       adultkid = 3,
       dataset  = adult,
       outname  = need );

%nowbox (logtext = End &FileName version &Version ) ;

*--------------------------------------------------------------------------*
|  Reset the log and output files back to the defaults                     |
*--------------------------------------------------------------------------*;

proc printto ;
run ;

filename _all_ clear ;
