*--------------------------------------------------------------------------*;
%let ProgramName = test ;
%let Extension   = sas ;
%let Version     = 3.5 ;
%let Root        = /data/cahpsmmc/analysis_program/version 3.5 ;
%let ProgramPath = /programs/ ;
%let Created     = 24 Aug 2005 ;
%let Author      = Matthew J. Cioffi ;
%let Type        = Program ;

*--------------------------------------------------------------------------*
| What are the required input data sets and macros needed by the program.  |
      MACROS: cahps35.sas
      DATA  : plandtal.dat
              test.sas7bdat
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| What are the permanent output datasets created by the program or where   |
| are all the datasets stored if there are many.                           |
      The data sets created by the CAHPS macro.
*--------------------------------------------------------------------------*;

***********
* Purpose *
     Program to test the functionality of the CAHPS 3.5 macro.  The data
     set, test, contains fictitious data for Dichotomous, Overall Rating
     scale (0 - 10), How Often scale (1 - 4), Problem Scale (1 - 3) and
     adjuster variables.  This program is similar to a control file that
     could be set up for actual CAHPS data sets.

     It prepares the data set by cleaning, reverse coding and adding
     variables that are needed by the CAHPS macro.  After the preparation,
     several CAHPS macro calls are made for each type of variable,
     Dichotomous, Overall Rating, How Often and Problem Scales.

*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| Macro Variables                                                          |
*--------------------------------------------------------------------------*;
%let Filename    = &ProgramName..&Extension  ;

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
|     in       -  SAS data set to be used as input.                        |
|     out      -  Permanent SAS data sets created by Macro stored here.    |
|                   ** OUT is required by the CAHPS macro **               |
|     library  -  Location of the library for using permanent formats.     |
|                                                                          |
|     logfile  -  Path and filename for the SAS log file.                  |
|     outfile  -  Path and filename for storing SAS procedure output.      |
|     cahps    -  Path and filename for the CAHPS macro.                   |
|     plan_dat -  Path and filename for the plan detail information.       |
*--------------------------------------------------------------------------*;

libname in        "&root./sasdata/" ;
libname out       "&root./sasdata/helptest/" ;
libname library   "&root./sascatalog/" ;

filename _all_ clear ;
filename logfile  "&root./output/logs/&ProgramName..log" ;
filename outfile  "&root./output/&ProgramName..txt" ;
filename cahps    "&root./programs/cahps35.sas" ;
filename plan_dat "&root./data_other/plandtal.dat" ;

*--------------------------------------------------------------------------*
| Redirect output and logs to the file referenced by outfile and logfile.  |
*--------------------------------------------------------------------------*;

proc printto print = outfile new
             log   = logfile new
             ;
run;


*--------------------------------------------------------------------------*
|   Clear all titles and footnotes                                         |
*--------------------------------------------------------------------------*;

title ;
footnote ;

run ;

*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox ( logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
        ;
run ;


*--------------------------------------------------------------------------*
| Begin Preparation of data set for CAHPS macro                            |
*--------------------------------------------------------------------------*;

data test ( drop = i ) ;
   set in.test ;

*--------------------------------------------------------------------------*
| Recodes numeric plan variables to character to simplify interpretation   |
| of the resultant data sets and reports.                                  |
*--------------------------------------------------------------------------*;

   length plan $ 16 ;

   if      planid = 1 then plan = 'HMO_A_URBAN' ;
   else if planid = 2 then plan = 'HMO_B_URBAN' ;
   else if planid = 7 then plan = 'HMO_C_URBAN' ;
   else if planid = 4 then plan = 'HMO_B_RURAL' ;
   else if planid = 5 then plan = 'HMO_C_RURAL' ;
   else if planid = 6 then plan = 'HMO_BE_1' ;

*--------------------------------------------------------------------------*
| If subsetting by low and high users is desired then the CAHPS macro      |
| needs to have a variable named VISTIS where a value less than 3          |
| indicates low users and a value greater than or equal 3 indicates high   |
| users. If not subsetting, then no VISITS variable is needed.             |
*--------------------------------------------------------------------------*;

*  visits = q21 ;

*--------------------------------------------------------------------------*
| If there are children records in the data set and the user wants the     |
| the macro to process them as children records, then a CHILD variable     |
| needs to be created.  For each record that is a child the value should   |
| be set to 1, otherwise it can be set to any other number.  If the user   |
| does not supply the CHILD variable, the macro creates one and sets it to |
| zero.                                                                    |
*--------------------------------------------------------------------------*;

*  child = 1 ;

*--------------------------------------------------------------------------*
| Recodes dichotomous, yes/no, variables from 1/2 to 1/0.                  |
| For the CAHPS Adult core survey add questions 13 and 22 to the array.    |
*--------------------------------------------------------------------------*;

   array yn q05 ;
   do i = 1 to dim ( yn ) ;
           if yn [i] = 0 then yn [i] = . ;
      else if yn [i] = 2 then yn [i] = 0 ;
   end ;

*--------------------------------------------------------------------------*
| REVERSE code items for which never = positive and always = negative.     |
*--------------------------------------------------------------------------*;

   array rev q24 ;
   do i = 1 to dim ( rev ) ;
      if rev [i] in (1, 2, 3, 4) then rev [i] = 5 - rev [i] ;
      else                            rev [i] = . ;
   end ;

*--------------------------------------------------------------------------*
| Cleans variables general health rating (q39), age (q40), and gender(q41).|
*--------------------------------------------------------------------------*;

   if q39 not in (1, 2, 3, 4, 5)       then q39 = . ;
   if q40 not in (1, 2, 3, 4, 5, 6, 7) then q40 = . ;
   if q41 not in (1, 2)                then q41 = . ;
run ;

*--------------------------------------------------------------------------*
| ** End Peparation of data set for CAHPS macro **                         |
*--------------------------------------------------------------------------*;


*--------------------------------------------------------------------------*
| Include and compile needed macros.                                       |
*--------------------------------------------------------------------------*;

%include cahps ;



*--------------------------------------------------------------------------*
| Executes cahps macro - Dichotomous Scale                                 |
*--------------------------------------------------------------------------*;

%cahps(var      = q05,
       vartype  = 1,
       name     = Find personal doctor,
       adjuster = Q39 Q40,
       adj_bars = 1,
       bar_stat = 1,
       impute   = 1,
       even_wgt = 0,
       kp_resid = 1,
       adultkid = 3,
       visits   = 1,
       pvalue   = 0.05,
       change   = 0,
       meandiff = 0,
       wgtdata  = 2,
       id_resp  = id,
       subset   = 1,
       dataset  = test,
       outname  = test1) ;

%cahps(var      = q05,
       vartype  = 1,
       recode   = 1,
       name     = Find personal doctor,
       adjuster = q39 Q40,
       impute   = 1,
       even_wgt = 0,
       adultkid = 0,
       visits   = 1,
       pvalue   = 0.05,
       change   = 0,
       meandiff = 0,
       wgtdata  = 1,
       subset   = 3,
       dataset  = test,
       outname  = test2) ;

%cahps(var      = q05,
       vartype  = 1,
       name     = Find personal doctor,
       adjuster = ,
       impute   = 1,
       even_wgt = 0,
       adultkid = 0,
       visits   = 1,
       pvalue   = 0.05,
       change   = 0,
       meandiff = 0,
       wgtdata  = 2,
       subset   = 2,
       dataset  = test,
       outname  = test3) ;


*-------------------------------------------------------------------------*
| Executes cahps macro - Rating Scale                                      |
*--------------------------------------------------------------------------*;

%cahps(var      = q38,
       vartype  = 2,
       name     = Rate Plan,
       adjuster = q39 Q40,
       impute   = 1,
       adultkid = 0,
       dataset  = test,
       outregre = 1,
       outname  = rpadj) ;

%cahps(var      = q38,
       vartype  = 2,
       name     = Rate Plan,
       adjuster = ,
       impute   = 1,
       adultkid = 0,
       dataset  = test,
       outname  = rplan) ;

%cahps(var      = q38,
       vartype  = 2,
       recode   = 1,
       name     = Rate Plan,
       adjuster = q39 Q40,
       impute   = 1,
       adultkid = 0,
       wgtdata  = 2,
       dataset  = test,
       outname  = rpc) ;

*--------------------------------------------------------------------------*
| Executes cahps macro - Composite Items.                                  |
*--------------------------------------------------------------------------*;

%cahps(var      = q15 q17 q19 q24,
       vartype  = 3,
       name     = Getting Care Quickly,
       adjuster = q39 Q40,
       impute   = 1,
       adultkid = 0,
       wgtdata  = 2,
       dataset  = test,
       outname  = quick ) ;

%cahps(var      = q06 q10 q22 q23,
       vartype  = 4,
       name     = Getting Care Needed,
       adjuster = ,
       impute   = 1,
       adultkid = 0,
       dataset  = test,
       outname  = need  ) ;


%nowbox (logtext= End &FileName version &Version ) ;
run ;


*--------------------------------------------------------------------------*
|  Reset the log and output files back to the defaults                     |
*--------------------------------------------------------------------------*;

proc printto ;
run ;

filename _all_ clear ;
